package #
Date::Manip::Offset::off113;
# Copyright (c) 2008-2017 Sullivan Beck.  All rights reserved.
# This program is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.

# This file was automatically generated.  Any changes to this file will
# be lost the next time 'tzdata' is run.
#    Generated on: Tue May 30 10:44:03 EDT 2017
#    Data version: tzdata2017b
#    Code version: tzcode2017b

# This module contains data from the zoneinfo time zone database.  The original
# data was obtained from the URL:
#    ftp://ftp.iana.org/tz

use strict;
use warnings;
require 5.010000;

our ($VERSION);
$VERSION='6.60';
END { undef $VERSION; }

our ($Offset,%Offset);
END {
   undef $Offset;
   undef %Offset;
}

$Offset        = '+05:00:00';

%Offset        = (
   0 => [
      'asia/dushanbe',
      'asia/tashkent',
      'asia/aqtau',
      'asia/aqtobe',
      'asia/ashgabat',
      'asia/atyrau',
      'asia/oral',
      'asia/samarkand',
      'asia/yekaterinburg',
      'indian/kerguelen',
      'asia/karachi',
      'indian/maldives',
      'etc/gmt+5',
      'r',
      'antarctica/mawson',
      'asia/bishkek',
      'asia/qyzylorda',
      'indian/chagos',
      'asia/omsk',
      'asia/almaty',
      'antarctica/davis',
      ],
   1 => [
      'asia/baku',
      'asia/yerevan',
      'europe/samara',
      'indian/mauritius',
      'asia/tbilisi',
      'asia/oral',
      'asia/aqtau',
      'asia/atyrau',
      'asia/aqtobe',
      'asia/ashgabat',
      'asia/qyzylorda',
      'asia/yekaterinburg',
      'europe/astrakhan',
      'europe/kirov',
      'europe/ulyanovsk',
      'europe/saratov',
      'europe/volgograd',
      'asia/tehran',
      'europe/moscow',
      ],
);

1;
